@@ -1,8 +1,8 @@
 import logging
 from datetime import datetime, time, date
 from typing import Optional, Any
+from django.core.exceptions import ValidationError
 from django.utils.translation import gettext as _
-from rest_framework.exceptions import ValidationError
 import pytz
 from django.utils.dateparse import parse_datetime as django_parse_datetime
 from django.utils.dateparse import parse_date as django_parse_date
