@@ -50,13 +50,13 @@ def get_geo_ip(ip: str, exceptions: bool = False, timeout: int = 10) -> dict:
     :return: dict
     """
     try:
+        if not hasattr(settings, "IPSTACK_TOKEN") or not settings.IPSTACK_TOKEN:
+            raise Exception("get_geo_ip() requires IPSTACK_TOKEN defined in Django settings")
         res = requests.get(
             "http://api.ipstack.com/{}?access_key={}&format=1".format(ip, settings.IPSTACK_TOKEN), timeout=timeout
         )
         if res.status_code != 200:
-            if exceptions:
-                raise Exception("api.ipstack.com HTTP {}".format(res.status_code))
-            return {}
+            raise Exception("api.ipstack.com HTTP {}".format(res.status_code))
         return res.json()
     except Exception as e:
         msg = "geoip({}) failed: {}".format(ip, e)
